@@ -9,7 +9,7 @@ from pprint import pformat
 
 from .parsers import get_download_data, ANIMELISTSITES
 from .downloader import batch_download
-from .options import OPTIONS, _update_dict
+from .options import OPTIONS, _update_options
 from .tools import repair
 
 logger = logging.getLogger('animethemes-dl')
@@ -35,6 +35,14 @@ utils.add_argument(
     type=realpath,
     help="path to ffmpeg, in case it's not in PATH"
 )
+utils.set_defaults(id3v2_version=4)
+utils.add_argument(
+    '--use-id3v23',
+    action='store_const',
+    dest='id3v2_version',
+    const=3,
+    help="Uses ID3v2.3 instead of v2.4. For older systems that do not support v2.4."
+)
 utils.add_argument(
     '-s','--settings','--options',
     type=realpath,
@@ -326,7 +334,7 @@ def load_settings(settings):
 def parse_args(args):
     filters = get_filters(args)
     args.loglevel = LOGLEVELS[args.loglevel]
-    options = _update_dict(OPTIONS,
+    options = _update_options(OPTIONS,
     {
         "animelist": {
             "username": args.username,
@@ -373,9 +381,10 @@ def parse_args(args):
         "statuses": args.statuses,
         "quiet": args.loglevel>logging.CRITICAL,
         "no_colors": args.no_color,
-        "ffmpeg": args.ffmpeg
+        "ffmpeg": args.ffmpeg,
+        "id3v2_version": args.id3v2_version
     })
-    return _update_dict(options,load_settings(args.settings))
+    return _update_options(options,load_settings(args.settings))
 
 def check_errors(options):
     errors = []
