@@ -45,7 +45,6 @@ class DownloadOptions(TypedDict):
     ascii: bool
     timeout: int
     retries: int
-    sort: str
     max_cache_age: int
     force_videos: List[int]
 
@@ -59,4 +58,5 @@ class Options(TypedDict):
     quiet: bool
     no_colors: bool
     ffmpeg: PathLike
+    id3v2_version: Literal[3,4]
     ignore_prompts: bool
